==> v1.76.zip: chrono/tests/manager/test_category.py <==
# -*- coding: utf-8 -*-

from __future__ import unicode_literals

import pytest
from django.contrib.auth.models import Group, User

from chrono.agendas.models import Agenda, Category

from .test_all import login

pytestmark = pytest.mark.django_db


@pytest.fixture
def manager_user():
    managers_group, _ = Group.objects.get_or_create(name='Managers')
    try:
        user = User.objects.get(username='manager')
    except User.DoesNotExist:
        user = User.objects.create_user('manager', password='manager')
    user.groups.set([managers_group])
    return user


@pytest.fixture
def admin_user():
    try:
        user = User.objects.get(username='admin')
    except User.DoesNotExist:
        user = User.objects.create_superuser('admin', email=None, password='admin')
    return user


def test_list_categories_as_manager(app, manager_user):
    agenda = Agenda(label=u'Foo Bar')
    agenda.view_role = manager_user.groups.all()[0]
    agenda.save()
    app = login(app, username='manager', password='manager')
    app.get('/manage/categories/', status=403)

    resp = app.get('/manage/', status=200)
    assert 'Categories' not in resp.text


def test_add_category(app, admin_user):
    app = login(app)
    resp = app.get('/manage/', status=200)
    resp = resp.click('Categories')
    resp = resp.click('New')
    resp.form['label'] = 'Foo bar'
    resp = resp.form.submit()
    category = Category.objects.latest('pk')
    assert resp.location.endswith('/manage/categories/')
    assert category.label == 'Foo bar'
    assert category.slug == 'foo-bar'


def test_add_category_as_manager(app, manager_user):
    agenda = Agenda(label=u'Foo Bar')
    agenda.view_role = manager_user.groups.all()[0]
    agenda.save()
    app = login(app, username='manager', password='manager')
    app.get('/manage/category/add/', status=403)


def test_edit_category(app, admin_user):
    category = Category.objects.create(label='Foo bar')

    app = login(app)
    resp = app.get('/manage/categories/', status=200)
    resp = resp.click(href='/manage/category/%s/edit/' % category.pk)
    resp.form['label'] = 'Foo bar baz'
    resp.form['slug'] = 'baz'
    resp = resp.form.submit()
    assert resp.location.endswith('/manage/categories/')
    category.refresh_from_db()
    assert category.label == 'Foo bar baz'
    assert category.slug == 'baz'


def test_edit_category_as_manager(app, manager_user):
    agenda = Agenda(label=u'Foo Bar')
    agenda.view_role = manager_user.groups.all()[0]
    agenda.save()
    category = Category.objects.create(label='Foo bar')
    app = login(app, username='manager', password='manager')
    app.get('/manage/category/%s/edit/' % category.pk, status=403)


def test_delete_category(app, admin_user):
    category = Category.objects.create(label='Foo bar')

    app = login(app)
    resp = app.get('/manage/categories/', status=200)
    resp = resp.click(href='/manage/category/%s/delete/' % category.pk)
    resp = resp.form.submit()
    assert resp.location.endswith('/manage/categories/')
    assert Category.objects.exists() is False


def test_delete_category_as_manager(app, manager_user):
    agenda = Agenda(label=u'Foo Bar')
    agenda.view_role = manager_user.groups.all()[0]
    agenda.save()
    category = Category.objects.create(label='Foo bar')
    app = login(app, username='manager', password='manager')
    app.get('/manage/category/%s/delete/' % category.pk, status=403)

==> v2.0.zip: chrono/tests/manager/test_category.py <==
import pytest

from chrono.agendas.models import Agenda, Category

from .test_all import login

pytestmark = pytest.mark.django_db


def test_list_categories_as_manager(app, manager_user):
    agenda = Agenda(label='Foo Bar')
    agenda.view_role = manager_user.groups.all()[0]
    agenda.save()
    app = login(app, username='manager', password='manager')
    app.get('/manage/categories/', status=403)

    resp = app.get('/manage/', status=200)
    assert 'Categories' not in resp.text


def test_add_category(app, admin_user):
    app = login(app)
    resp = app.get('/manage/', status=200)
    resp = resp.click('Categories')
    resp = resp.click('New')
    resp.form['label'] = 'Foo bar'
    resp = resp.form.submit()
    category = Category.objects.latest('pk')
    assert resp.location.endswith('/manage/categories/')
    assert category.label == 'Foo bar'
    assert category.slug == 'foo-bar'


def test_add_category_as_manager(app, manager_user):
    agenda = Agenda(label='Foo Bar')
    agenda.view_role = manager_user.groups.all()[0]
    agenda.save()
    app = login(app, username='manager', password='manager')
    app.get('/manage/category/add/', status=403)


def test_edit_category(app, admin_user):
    category = Category.objects.create(label='Foo bar')

    app = login(app)
    resp = app.get('/manage/categories/', status=200)
    resp = resp.click(href='/manage/category/%s/edit/' % category.pk)
    resp.form['label'] = 'Foo bar baz'
    resp.form['slug'] = 'baz'
    resp = resp.form.submit()
    assert resp.location.endswith('/manage/categories/')
    category.refresh_from_db()
    assert category.label == 'Foo bar baz'
    assert category.slug == 'baz'


def test_edit_category_as_manager(app, manager_user):
    agenda = Agenda(label='Foo Bar')
    agenda.view_role = manager_user.groups.all()[0]
    agenda.save()
    category = Category.objects.create(label='Foo bar')
    app = login(app, username='manager', password='manager')
    app.get('/manage/category/%s/edit/' % category.pk, status=403)


def test_delete_category(app, admin_user):
    category = Category.objects.create(label='Foo bar')

    app = login(app)
    resp = app.get('/manage/categories/', status=200)
    resp = resp.click(href='/manage/category/%s/delete/' % category.pk)
    resp = resp.form.submit()
    assert resp.location.endswith('/manage/categories/')
    assert Category.objects.exists() is False


def test_delete_category_as_manager(app, manager_user):
    agenda = Agenda(label='Foo Bar')
    agenda.view_role = manager_user.groups.all()[0]
    agenda.save()
    category = Category.objects.create(label='Foo bar')
    app = login(app, username='manager', password='manager')
    app.get('/manage/category/%s/delete/' % category.pk, status=403)
